@@ -1,5 +1,5 @@
 #!/bin/sh
 mkdir ~/laz-temp/indy
+mv compiler/indy-10.2.0.3.tar.gz ~/laz-temp/indy/indy-10.2.0.3.tar.gz
 cd ~/laz-temp/indy
-wget http://www.indyproject.org/Sockets/fpc/indy-10.2.0.3.tar.gz
 tar -zxvf ./indy-10.2.0.3.tar.gz
